@@ -5,9 +5,9 @@
 
 ;; Author: Enami Tsugutomo <enami@ba2.so-net.or.jp>
 ;; Maintainer: Mikio Nakajima <minakaji@osaka.email.ne.jp>
-;; Version: $Id: skk-isearch.el,v 1.2 2000/07/10 04:34:00 yoshiki Exp $
+;; Version: $Id: skk-isearch.el,v 1.3 2000/10/06 08:59:41 youngs Exp $
 ;; Keywords: japanese
-;; Last Modified: $Date: 2000/07/10 04:34:00 $
+;; Last Modified: $Date: 2000/10/06 08:59:41 $
 
 ;; This file is part of SKK.
 
@@ -394,8 +394,8 @@ kakutei'ed and erase the buffer contents."
 	       (add-hook 'pre-command-hook 'skk-pre-command nil 'local)))))
 
 (defun skk-isearch-incomplete-message (&optional prefix)
-  "Show message when kana kanji convertion is in progress.
-Optional argument PREFIX is apppended if given."
+  "Show message when kana kanji conversion is in progress.
+Optional argument PREFIX is appended if given."
   (let ((isearch-message (concat isearch-message
 				 skk-isearch-incomplete-message prefix)))
     (isearch-message)))
